//
//  ViewController.swift
//  JUnionDemo
//
//  Created by Allan on 2020/9/15.
//  Copyright © 2020 hxhg. All rights reserved.
//

import UIKit
import JUnion
var logData = [String]()
let logTableView = UITableView(frame: CGRect(x: 0, y: 100, width: 200, height: 250), style: .plain)

var statusBarHeight: CGFloat {
    if UIScreen.main.bounds.height > 811 {
        return 44
    } else {
        return 20
    }
}
var gSafeAreaInsets: UIEdgeInsets {
    get {
        if UIScreen.main.bounds.height > 811 {
            return UIEdgeInsets(top: 44, left: 0, bottom: 34, right: 0)
        } else {
            return UIEdgeInsets(top: 20, left: 0, bottom: 0, right: 0)
        }
    }
}

class ViewController: UIViewController, JUVideoDelegate {
    var channelVC:JURootViewController!
    override func viewDidLoad() {
        super.viewDidLoad()
        self.channelVC = JUService.getChannelListViewController(delegate: self)
        self.channelVC.view.frame = CGRect(x: 0, y: statusBarHeight, width: self.view.frame.width, height: self.view.frame.height - statusBarHeight - gSafeAreaInsets.bottom - 49)

        self.view.addSubview((self.channelVC.view)!)
        self.addChild(self.channelVC);
        logTableView.delegate = self
        logTableView.dataSource = self
        logTableView.register(UITableViewCell.self, forCellReuseIdentifier: "logCell")
        logTableView.estimatedRowHeight = 0
        logTableView.estimatedSectionFooterHeight = 0
        logTableView.sectionFooterHeight = 0
        logTableView.separatorStyle = .none
        logTableView.alpha = 0.8
        logTableView.isUserInteractionEnabled = false
        UIApplication.shared.windows.last?.addSubview(logTableView)

    }
    

    ///MARK: JUVideoDelegate
    func playerStart(videoInfo: JUFeedVideoData, isAD: Bool) {
        print(">>>>>>>>> playerStart videoID:\(videoInfo.video_id ?? "")")
    }
    
    func playerPause(videoInfo: JUFeedVideoData, isPause: Bool, isAD: Bool) {
        print(">>>>>>>>> playerPause videoID:\(videoInfo.video_id ?? "")  isPause:\(isPause)")
        logData.append("\(isPause ? "视频暂停" : "视频播放")")
        logTableView.reloadData()
    }
    
    func playerEnd(videoInfo: JUFeedVideoData, isAD: Bool) {
        print(">>>>>>>>> playerEnd videoID:\(videoInfo.video_id ?? "")")
    }
    
    func playerError(videoInfo: JUFeedVideoData, error: Error?, isAD: Bool) {
        print(">>>>>>>>> playerError videoID:\(videoInfo.video_id ?? "")")
    }
        
    func clickShareBtn(videoInfo: JUFeedVideoData, isMain: Bool) {
        if isMain {
//            self.channelVC.disLikeVideo(feed: videoInfo)
        }
        print(">>>>>>>>> clickShareBtn videoID:\(videoInfo.video_id ?? "")  isMain: \(isMain)")
    }
    
    func clickPraiseBtn(videoInfo: JUFeedVideoData, isPraise: Bool, isAD: Bool) {
        print(">>>>>>>>> clickPraiseBtn videoID:\(videoInfo.video_id ?? "")  isPraise: \(isPraise)")
        logData.append("\(isPraise ? "点赞" : "取消点赞")")
        logTableView.reloadData()
    }
    
    func gotoCPPage(videoInfo: JUFeedVideoData) {
        print(">>>>>>>>> gotoCPPage cpID:\(videoInfo.provider?.id ?? "")")
        logData.append("进入CP页")
        logTableView.reloadData()
        UIApplication.shared.windows.last?.addSubview(logTableView)
    }
    
    func gotoPlayerPage(videoInfo: JUFeedVideoData) {
        print(">>>>>>>>> gotoPlayerPage videoID:\(videoInfo.video_id ?? "")")
        logData.append("进入播放页")
        logTableView.reloadData()
        UIApplication.shared.windows.last?.addSubview(logTableView)
    }
    
    func gotoFeedPage(channelID: String) {
        logData.append("进入feed页：\(channelID)")
        logTableView.reloadData()
    }
    
    func adShowWith(ylID: String, reqId: String, type: Int) {
        print(">>>>>>>>> adShow ylid: \(ylID)  reqid: \(reqId)  type: \(type)")
    }
    
    func adClickWith(ylID: String, reqId: String, type: Int) {
        print(">>>>>>>>> adClick ylid: \(ylID)  reqid: \(reqId)  type: \(type)")
    }
}

extension ViewController: UITableViewDelegate, UITableViewDataSource
{
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return logData.count
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: "logCell", for: indexPath)
        cell.textLabel?.text = logData[indexPath.row]
        tableView.scrollToRow(at: IndexPath(row: logData.count - 1, section: 0), at: .bottom, animated: true)
        return cell
    }
}

